@@ -1,6 +1,6 @@
 package Net::WebSocket;
 
-our $VERSION = '0.04-TRIAL2';
+our $VERSION = '0.05-TRIAL2';
 
 =encoding utf-8
 
@@ -10,19 +10,23 @@ Net::WebSocket - WebSocket in Perl
 
 =head1 SYNOPSIS
 
+    use Net::WebSocket::Handshake::Client ();
+    use Net::WebSocket::HTTP_R ();
+
     my $handshake = Net::WebSocket::Handshake::Client->new(
         uri => $uri,
     );
 
-    syswrite $inet, $handshake->create_header_text() . "\x0d\x0a" or die $!;
+    syswrite $inet, $handshake->to_string() or die $!;
 
     #You can parse HTTP headers however you want;
     #Net::WebSocket makes no assumptions about this.
-    my $req = HTTP::Response->parse($hdrs_txt);
+    my $resp = HTTP::Response->parse($hdrs_txt);
 
-    #XXX More is required for the handshake validation in production!
-    my $accept = $req->header('Sec-WebSocket-Accept');
-    $handshake->validate_accept_or_die($accept);
+    #If you use an interface that’s compatible with HTTP::Response,
+    #then you can take advantage of this convenience function;
+    #otherwise you’ll need to do a bit more work.
+    Net::WebSocket::HTTP_R::handshake_parse_response( $handshake, $resp );
 
     #See below about IO::Framed
     my $parser = Net::WebSocket::Parser->new(
@@ -67,14 +71,14 @@ a UNIX socket, ordinary TCP/IP, some funky C<tie()>d object, or whatever.
 Net::WebSocket also “has no opinions” about how you should do I/O or HTTP
 headers. There are too many different ways to accomplish HTTP header
 management in particular for it to be sensible for a WebSocket library to
-impose any one approach. As a result of this, Net::WebSocket can likely
-fit your project; however, it won’t absolve you of the need to know some
-things about the WebSocket protocol itself. There are some examples
+impose any one approach. As a result of this, Net::WebSocket can probably
+fit your project with minimal overhead. There are some examples
 of how you might write complete applications (client or server)
-in the distribution’s C<demo/> directory.
+in the distribution’s F<demo/> directory.
 
-Net::WebSocket is not a “quick” WebSocket solution; for that,
-check out L<Mojolicious>. Net::WebSocket’s purpose is to support anything
+Net::WebSocket is not a “quick” WebSocket solution; L<Mojolicious> and
+the like fill that role amply.
+Net::WebSocket’s purpose is to support anything
 that the WebSocket protocol itself can do, as lightly as possible and without
 prejudice as to how you want to do it: extensions, blocking/non-blocking I/O,
 arbitrary HTTP headers, etc. Net::WebSocket will likely require more of an
